@@ -38,8 +38,6 @@ from pylav.envvars import (
     TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS,
     TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS,
     TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS,
-    USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE,
-    USE_BUNDLED_EXTERNAL_PYLAV_NODE,
 )
 from pylav.events import Event
 from pylav.exceptions import (
@@ -66,7 +64,7 @@ from pylav.sql.clients.player_state_db_manager import PlayerStateDBManager
 from pylav.sql.clients.playlist_manager import PlaylistConfigManager
 from pylav.sql.clients.query_manager import QueryCacheManager
 from pylav.sql.clients.updater import UpdateSchemaManager
-from pylav.sql.models import LibConfigModel
+from pylav.sql.models import LibConfigModel, NodeModel
 from pylav.tracks import Track
 from pylav.types import BotT, CogT, ContextT, InteractionT, LavalinkResponseT
 from pylav.utils import PyLavContext, SingletonMethods, _get_context, _process_commands, _Singleton, add_property
@@ -327,45 +325,42 @@ class Client(metaclass=_Singleton):
                             client_secret = None
                         await self._lib_config_manager.initialize()
                         await self._update_schema_manager.run_updates()
+                        await NodeModel.create_managed(id=self.bot.user.id)
                         await self._radio_manager.initialize()
                         await self._player_manager.initialize()
-                        self._config = await self._lib_config_manager.get_config(
-                            config_folder=self._config_folder,
-                            java_path=JAVA_EXECUTABLE,
-                            enable_managed_node=True,
-                            auto_update_managed_nodes=True,
-                            localtrack_folder=self._config_folder / "music",
-                            use_bundled_lava_link_external=USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE,
-                            use_bundled_pylav_external=USE_BUNDLED_EXTERNAL_PYLAV_NODE,
-                        )
+                        await self.player_config_manager.initialize_global_config()
+                        self._config = self._lib_config_manager.get_config()
+                        config_data = await self._config.fetch_all()
+                        java_path = config_data["java_path"]
+                        config_folder = config_data["config_folder"]
+                        localtrack_folder = config_data["localtrack_folder"]
+                        auto_update_managed_nodes = config_data["auto_update_managed_nodes"]
+                        enable_managed_node = config_data["enable_managed_node"]
 
-                        if (
-                            self._config.java_path != JAVA_EXECUTABLE
-                            and JAVA_EXECUTABLE != "java"
-                            and os.path.exists(JAVA_EXECUTABLE)
-                        ):
-                            self._config.java_path = JAVA_EXECUTABLE
-                            await self._config.save()
-                        LOGGER.info("Config folder: %s", self._config.config_folder)
-                        LOGGER.info("Localtracks folder: %s", self._config.localtrack_folder)
-                        auto_update_managed_nodes = self._config.auto_update_managed_nodes
-                        self.enable_managed_node = self._config.enable_managed_node
-                        self._config_folder = aiopath.AsyncPath(self._config.config_folder)
-                        localtrack_folder = aiopath.AsyncPath(self._config.localtrack_folder)
-                        data = await self._node_config_manager.get_bundled_node_config()
+                        if java_path != JAVA_EXECUTABLE and os.path.exists(JAVA_EXECUTABLE):
+                            await self._config.update_java_path(JAVA_EXECUTABLE)
+
+                        LOGGER.info("Config folder: %s", config_folder)
+                        LOGGER.info("Localtracks folder: %s", localtrack_folder)
+                        self.enable_managed_node = enable_managed_node
+                        self._config_folder = aiopath.AsyncPath(config_folder)
+                        localtrack_folder = aiopath.AsyncPath(localtrack_folder)
+                        bundled_node_config = self._node_config_manager.bundled_node_config()
                         if not await asyncstdlib.all([client_id, client_secret]):
-                            spotify_data = data.yaml["plugins"]["topissourcemanagers"]["spotify"]
+                            yaml_data = await bundled_node_config.fetch_yaml()
+                            spotify_data = yaml_data["plugins"]["topissourcemanagers"]["spotify"]
                             client_id = spotify_data["clientId"]
                             client_secret = spotify_data["clientSecret"]
                         elif await asyncstdlib.all([client_id, client_secret]):
+                            yaml_data = await bundled_node_config.fetch_yaml()
                             if (
-                                data.yaml["plugins"]["topissourcemanagers"]["spotify"]["clientId"] != client_id
-                                or data.yaml["plugins"]["topissourcemanagers"]["spotify"]["clientSecret"]
+                                yaml_data["plugins"]["topissourcemanagers"]["spotify"]["clientId"] != client_id
+                                or yaml_data["plugins"]["topissourcemanagers"]["spotify"]["clientSecret"]
                                 != client_secret
                             ):
-                                data.yaml["plugins"]["topissourcemanagers"]["spotify"]["clientId"] = client_id
-                                data.yaml["plugins"]["topissourcemanagers"]["spotify"]["clientSecret"] = client_secret
-                            await data.save()
+                                yaml_data["plugins"]["topissourcemanagers"]["spotify"]["clientId"] = client_id
+                                yaml_data["plugins"]["topissourcemanagers"]["spotify"]["clientSecret"] = client_secret
+                                await bundled_node_config.update_yaml(yaml_data)
                         self._spotify_client_id = client_id
                         self._spotify_client_secret = client_secret
                         self._spotify_auth = ClientCredentialsFlow(
@@ -385,7 +380,7 @@ class Client(metaclass=_Singleton):
                             )
                             and self.enable_managed_node
                         ):
-                            await self._local_node_manager.start(java_path=self._config.java_path)
+                            await self._local_node_manager.start(java_path=java_path)
                         else:
                             self._local_node_manager.ready.set()
                         await self.node_manager.connect_to_all_nodes()
@@ -398,22 +393,26 @@ class Client(metaclass=_Singleton):
                             and self.enable_managed_node
                         ):
                             await self._local_node_manager.wait_until_connected()
-                        await self.player_manager.restore_player_states()
                         time_now = datetime.datetime.now(tz=datetime.timezone.utc)
-                        if self._config.next_execution_update_bundled_playlists is None:
-                            self._config.next_execution_update_bundled_playlists = time_now + datetime.timedelta(
-                                minutes=5
+                        if await self._config.fetch_next_execution_update_bundled_playlists() is None:
+                            await self._config.update_next_execution_update_bundled_playlists(
+                                time_now + datetime.timedelta(minutes=5, days=1)
                             )
 
-                        if self._config.next_execution_update_bundled_external_playlists is None:
-                            self._config.next_execution_update_bundled_external_playlists = (
-                                time_now + datetime.timedelta(minutes=10)
+                        if await self._config.fetch_next_execution_update_bundled_external_playlists() is None:
+                            await self._config.update_next_execution_update_bundled_external_playlists(
+                                time_now + datetime.timedelta(minutes=10, days=7)
                             )
 
-                        if self._config.next_execution_update_external_playlists is None:
-                            self._config.next_execution_update_external_playlists = time_now + datetime.timedelta(
-                                minutes=30
+                        if await self._config.fetch_next_execution_update_external_playlists() is None:
+                            await self._config.update_next_execution_update_external_playlists(
+                                time_now + datetime.timedelta(minutes=30)
                             )
+                        if await self.playlist_db_manager.count() == 0:
+                            await self.playlist_db_manager.update_bundled_playlists()
+                            await self.playlist_db_manager.update_bundled_external_playlists()
+
+                        await self.player_manager.restore_player_states()
 
                         self._scheduler.add_job(
                             self._query_cache_manager.delete_old,
@@ -426,12 +425,15 @@ class Client(metaclass=_Singleton):
                             id=f"{self.bot.user.id}-cache_delete_old",
                         )
 
+                        next_execution_update_bundled_playlists = (
+                            await self._config.fetch_next_execution_update_bundled_playlists()
+                        )
                         self._scheduler.add_job(
                             self.playlist_db_manager.update_bundled_playlists,
                             trigger="interval",
                             days=TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS,
                             max_instances=1,
-                            next_run_time=self._config.next_execution_update_bundled_playlists,
+                            next_run_time=next_execution_update_bundled_playlists,
                             replace_existing=True,
                             name="update_bundled_playlists",
                             coalesce=True,
@@ -441,15 +443,17 @@ class Client(metaclass=_Singleton):
 
                         LOGGER.info(
                             "Scheduling first run of Bundled Playlist update task to: %s",
-                            self._config.next_execution_update_bundled_playlists,
+                            next_execution_update_bundled_playlists,
+                        )
+                        next_execution_update_bundled_external_playlists = (
+                            await self._config.fetch_next_execution_update_bundled_external_playlists()
                         )
-
                         self._scheduler.add_job(
                             self.playlist_db_manager.update_bundled_external_playlists,
                             trigger="interval",
                             days=TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS,
                             max_instances=1,
-                            next_run_time=self._config.next_execution_update_bundled_external_playlists,
+                            next_run_time=next_execution_update_bundled_external_playlists,
                             replace_existing=True,
                             name="update_bundled_external_playlists",
                             coalesce=True,
@@ -459,15 +463,18 @@ class Client(metaclass=_Singleton):
 
                         LOGGER.info(
                             "Scheduling first run of Bundled External Playlist update task to: %s",
-                            self._config.next_execution_update_bundled_external_playlists,
+                            next_execution_update_bundled_external_playlists,
                         )
 
+                        next_execution_update_external_playlists = (
+                            await self._config.fetch_next_execution_update_external_playlists()
+                        )
                         self._scheduler.add_job(
                             self.playlist_db_manager.update_external_playlists,
                             trigger="interval",
                             days=TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS,
                             max_instances=1,
-                            next_run_time=self._config.next_execution_update_external_playlists,
+                            next_run_time=next_execution_update_external_playlists,
                             replace_existing=True,
                             name="update_external_playlists",
                             coalesce=True,
@@ -477,10 +484,8 @@ class Client(metaclass=_Singleton):
 
                         LOGGER.info(
                             "Scheduling first run of External Playlist update task to: %s",
-                            self._config.next_execution_update_external_playlists,
+                            next_execution_update_external_playlists,
                         )
-
-                        await self._config.save()
                         self._scheduler.start()
                         self.ready.set()
                         LOGGER.info("PyLav is ready")
@@ -504,10 +509,11 @@ class Client(metaclass=_Singleton):
         self._spotify_auth = ClientCredentialsFlow(
             client_id=self._spotify_client_id, client_secret=self._spotify_client_secret
         )
-        bundled_node_config = await self._node_config_manager.get_bundled_node_config()
-        bundled_node_config.yaml["plugins"]["topissourcemanagers"]["spotify"]["clientId"] = client_id
-        bundled_node_config.yaml["plugins"]["topissourcemanagers"]["spotify"]["clientSecret"] = client_secret
-        await bundled_node_config.save()
+        bundled_node_config = self._node_config_manager.bundled_node_config()
+        bundled_node_config_yaml = await bundled_node_config.fetch_yaml()
+        bundled_node_config_yaml["plugins"]["topissourcemanagers"]["spotify"]["clientId"] = client_id
+        bundled_node_config_yaml["plugins"]["topissourcemanagers"]["spotify"]["clientSecret"] = client_secret
+        await bundled_node_config.update_yaml(bundled_node_config_yaml)
 
     async def add_node(
         self,
@@ -523,7 +529,6 @@ class Client(metaclass=_Singleton):
         ssl: bool = False,
         search_only: bool = False,
         managed: bool = False,
-        skip_db: bool = False,
         yaml: dict | None = None,
         disabled_sources: list[str] = None,
         extras: dict = None,
@@ -556,8 +561,6 @@ class Client(metaclass=_Singleton):
             Whether the node should only be used for searching. Defaults to `False`.
         unique_identifier: :class:`in`
             A unique identifier for the node. Defaults to `None`.
-        skip_db: :class:`bool`
-            Whether the node should skip the database. Defaults to `False`.
         yaml: Optional[:class:`dict`]
             A dictionary of extra information to be stored in the node. Defaults to `None`.
         extras: Optional[:class:`dict`]
@@ -578,7 +581,6 @@ class Client(metaclass=_Singleton):
             ssl=ssl,
             search_only=search_only,
             unique_identifier=unique_identifier,
-            skip_db=skip_db,
             managed=managed,
             yaml=yaml,
             disabled_sources=disabled_sources,
@@ -960,7 +962,6 @@ class Client(metaclass=_Singleton):
         successful_tracks = []
         queries_failed = []
         track_count = 0
-
         for query in queries:
             node = await self.node_manager.find_best_node(
                 region=player.region if player else None,
@@ -981,11 +982,13 @@ class Client(metaclass=_Singleton):
                         queries_failed.append(query)
                     if track_b64:
                         track_count += 1
+                        new_query = await Query.from_base64(track_b64)
+                        new_query.merge(query, start_time=True)
                         successful_tracks.append(
                             Track(
                                 data=track_b64,
                                 node=node,
-                                query=await Query.from_base64(track_b64),
+                                query=new_query,
                                 requester=requester.id,
                             )
                         )
@@ -1142,8 +1145,8 @@ class Client(metaclass=_Singleton):
 
     async def remove_node(self, node_id: int):
         """Removes a node from the node manager"""
-        node = self.node_manager.get_node_by_id(node_id)
-        await self.node_manager.remove_node(node)
+        if node := self.node_manager.get_node_by_id(node_id):
+            await self.node_manager.remove_node(node)
 
     async def is_dj(
         self,
@@ -1162,8 +1165,8 @@ class Client(metaclass=_Singleton):
             user=user, guild=guild, additional_role_ids=None, additional_user_ids=None, bot=bot
         )
 
+    @staticmethod
     async def generate_mix_playlist(
-        self,
         *,
         video_id: str | None = None,
         user_id: str | None,
