@@ -1,6 +1,7 @@
 from __future__ import annotations
 
 import asyncio
+import typing
 from typing import TYPE_CHECKING, Any
 from uuid import uuid4
 
@@ -9,7 +10,7 @@ import asyncstdlib
 import ujson
 
 from pylav._logging import getLogger
-from pylav.constants import REGION_TO_COUNTRY_COORDINATE_MAPPING, SUPPORTED_SOURCES
+from pylav.constants import BUNDLED_NODES_IDS, PYLAV_NODES, REGION_TO_COUNTRY_COORDINATE_MAPPING, SUPPORTED_SOURCES
 from pylav.events import Event
 from pylav.exceptions import Unauthorized
 from pylav.filters import ChannelMix, Distortion, Equalizer, Karaoke, LowPass, Rotation, Timescale, Vibrato, Volume
@@ -199,8 +200,6 @@ class Node:
         Whether to use a ssl connection.
     """
 
-    _config: NodeModel
-
     def __init__(
         self,
         manager: NodeManager,
@@ -223,6 +222,7 @@ class Node:
         self._query_cls: Query = Query  # type: ignore
         self._manager = manager
         self._session = aiohttp.ClientSession(timeout=aiohttp.ClientTimeout(total=30), json_serialize=ujson.dumps)
+        self._config: NodeModel = self._manager._client.node_db_manager.get_node_config(unique_identifier)
         if unique_identifier is None:
             unique_identifier = str(uuid4())
         self._managed = managed
@@ -231,7 +231,6 @@ class Node:
         self._name = name or f"{self._region}-{self._host}-{unique_identifier}"
         self._extras = extras or {}
         self._disabled_sources = set(disabled_sources or [])
-        self._config = None  # type: ignore
 
         if self._manager.get_node_by_id(unique_identifier) is not None:
             raise ValueError(f"A Node with identifier:{unique_identifier} already exists")
@@ -467,14 +466,14 @@ class Node:
         if isinstance(other, Node):
             return self.identifier == other.identifier
         elif isinstance(other, NodeModel):
-            return self.host == other.yaml["server"]["address"] and self.port == other.yaml["server"]["port"]
+            return self.identifier == other.id
         return NotImplemented
 
     def __ne__(self, other):
         if isinstance(other, Node):
             return self.identifier != other.identifier
         elif isinstance(other, NodeModel):
-            return not (self.host == other.yaml["server"]["address"] and self.port == other.yaml["server"]["port"])
+            return self.identifier != other.id
         return NotImplemented
 
     def __hash__(self) -> int:
@@ -673,7 +672,8 @@ class Node:
             A dict representing tracks.
         """
         if not bypass_cache and (response := await self.node_manager.client.query_cache_manager.get_query(query)):
-            return (
+            return typing.cast(
+                LavalinkResponseT,
                 {"track": response.tracks[0]}
                 if first
                 else {
@@ -686,7 +686,7 @@ class Node:
                     if query.is_search
                     else "TRACK_LOADED",
                     "tracks": [{"track": track} async for track in AsyncIter(response.tracks)],
-                }
+                },
             )
 
         destination = f"{self.connection_protocol}://{self.host}:{self.port}/loadtracks"
@@ -926,6 +926,9 @@ class Node:
         #    using the correct node which will support local files instead of trying and failing most of the time.
         if not self.managed:
             self._capabilities.discard("local")
+        if self.identifier in PYLAV_NODES:
+            self._capabilities.discard("http")
+            self._capabilities.discard("local")
         # If not setup says these should be disabled remove them to trick the node to think they are disabled
         if self._sources:
             self._sources.difference_update(self._disabled_sources)
@@ -956,16 +959,13 @@ class Node:
         -------
         :class:`None`
         """
-        if self.managed:
+        if self.managed or self.identifier in BUNDLED_NODES_IDS:
             return
         unsupported = await self.get_unsupported_features()
-        if self._config is None:
-            self._config = await self.node_manager.client.node_db_manager.get_node_config(self.identifier)
-        currently_disabled = set(self.config.disabled_sources)
-        unsupported = unsupported.union(currently_disabled).union(sources)
-        self.config.disabled_sources = list(unsupported)
+        currently_disabled = set(await self.config.fetch_disabled_sources())
+        unsupported = list(unsupported.union(currently_disabled).union(sources))
+        await self.config.update_disabled_sources(unsupported)
         self._disabled_sources = unsupported
-        await self.config.save()
 
     @property
     def capabilities(self) -> set:
