@@ -3,6 +3,7 @@ from __future__ import annotations
 import asyncio
 import operator
 import os
+import typing
 from functools import partial
 from typing import TYPE_CHECKING
 
@@ -17,12 +18,12 @@ from pylav.constants import (
     PYLAV_BUNDLED_NODES_SETTINGS,
     REGION_TO_COUNTRY_COORDINATE_MAPPING,
 )
-from pylav.envvars import JAVA_EXECUTABLE, USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE, USE_BUNDLED_EXTERNAL_PYLAV_NODE
+from pylav.envvars import JAVA_EXECUTABLE
 from pylav.events import NodeConnectedEvent, NodeDisconnectedEvent
 from pylav.location import get_closest_region_name_and_coordinate
 from pylav.node import Node
 from pylav.player import Player
-from pylav.sql.models import NodeModel
+from pylav.sql.models import LibConfigModel
 from pylav.utils import sort_key_nodes
 
 if TYPE_CHECKING:
@@ -110,7 +111,6 @@ class NodeManager:
         reconnect_attempts: int = -1,
         ssl: bool = False,
         search_only: bool = False,
-        skip_db: bool = False,
         disabled_sources: list[str] = None,
         managed: bool = False,
         yaml: dict | None = None,
@@ -144,8 +144,6 @@ class NodeManager:
             Whether the node is search only. Defaults to `False`.
         unique_identifier: Optional[:class:`str`]
             A unique identifier for the node. Defaults to `None`.
-        skip_db: Optional[:class:`bool`]
-            Whether to skip the database creation op. Defaults to `False`.
         disabled_sources: Optional[:class:`list`[:class:`str`]]
             A list of sources to disable. Defaults to `None`.
         managed: Optional[:class:`bool`]
@@ -180,47 +178,22 @@ class NodeManager:
 
         LOGGER.info("[NODE-%s] Successfully added to Node Manager", node.name)
         LOGGER.verbose("[NODE-%s] Successfully added to Node Manager -- %r", node.name, node)
-        if skip_db:
-            data = dict(
-                yaml=yaml or {"server": {}, "lavalink": {"server": {}}},
-                id=unique_identifier,
-                ssl=ssl,
-                reconnect_attempts=reconnect_attempts,
-                search_only=search_only,
-                resume_key=resume_key,
-                resume_timeout=resume_timeout,
-                managed=managed,
-                name=name,
-                disabled_sources=disabled_sources or [],
-                extras=extras or {},
-            )
-            data["yaml"]["server"]["address"] = host  # type: ignore
-            data["yaml"]["server"]["port"] = port  # type: ignore
-            data["yaml"]["lavalink"]["server"]["password"] = password
-
-            node_config = NodeModel(**data)
-
-        node._config = (
-            node_config
-            if skip_db
-            else await self.client.node_db_manager.add_node(
-                host=host,
-                port=port,
-                password=password,
-                resume_key=resume_key,
-                resume_timeout=resume_timeout,
-                name=name,
-                reconnect_attempts=reconnect_attempts,
-                ssl=ssl,
-                search_only=search_only,
-                unique_identifier=unique_identifier,
-                disabled_sources=disabled_sources,
-                managed=managed,
-                yaml=yaml,
-                extras=extras or {},
-            )
+        node._config = await self.client.node_db_manager.update_node(
+            host=host,
+            port=port,
+            password=password,
+            resume_key=resume_key,
+            resume_timeout=resume_timeout,
+            name=name,
+            reconnect_attempts=reconnect_attempts,
+            ssl=ssl,
+            search_only=search_only,
+            unique_identifier=unique_identifier,
+            disabled_sources=disabled_sources,
+            managed=managed,
+            yaml=yaml,
+            extras=extras or {},
         )
-
         return node
 
     async def remove_node(self, node: Node) -> None:
@@ -235,7 +208,7 @@ class NodeManager:
         self.nodes.remove(node)
         LOGGER.info("[NODE-%s] Successfully removed Node", node.name)
         LOGGER.verbose("[NODE-%s] Successfully removed Node -- %r", node.name, node)
-        if node.identifier and not node.managed:
+        if node.identifier and not node.managed and node.identifier not in BUNDLED_NODES_IDS:
             await self.client.node_db_manager.delete(node.identifier)
             LOGGER.debug("[NODE-%s] Successfully deleted Node from database", node.name)
 
@@ -426,24 +399,24 @@ class NodeManager:
     async def connect_to_all_nodes(self) -> None:
         nodes_list = []
         for node in await self.client.node_db_manager.get_all_unamanaged_nodes():
+            node_data = await node.fetch_all()
             try:
                 if node in nodes_list:
                     LOGGER.warning(
                         "%s Node already added to connection pool - skipping duplicated connection - (%s:%s)",
-                        node.name,
-                        node.yaml["server"]["address"],
-                        node.yaml["server"]["port"],
+                        node_data["name"],
+                        node_data["yaml"]["server"]["address"],
+                        node_data["yaml"]["server"]["port"],
                     )
                     continue
-                if node.yaml["server"]["address"] in PYLAV_BUNDLED_NODES_SETTINGS:
-                    connection_arguments = PYLAV_BUNDLED_NODES_SETTINGS[node.yaml["server"]["address"]]
+                if node_data["yaml"]["server"]["address"] in PYLAV_BUNDLED_NODES_SETTINGS:
+                    connection_arguments = PYLAV_BUNDLED_NODES_SETTINGS[node_data["yaml"]["server"]["address"]]
                 else:
-                    connection_arguments = node.get_connection_args()
-                    connection_arguments["skip_db"] = node.id not in BUNDLED_NODES_IDS
+                    connection_arguments = await node.get_connection_args()
                 nodes_list.append(await self.add_node(**connection_arguments))
             except (ValueError, KeyError) as exc:
                 LOGGER.warning(
-                    "[NODE-%s] Invalid node, skipping ... id: %s - Original error: %s", node.name, node.id, exc
+                    "[NODE-%s] Invalid node, skipping ... id: %s - Original error: %s", node_data["name"], node.id, exc
                 )
                 continue
         if self._unmanaged_external_host and self._unmanaged_external_password:
@@ -460,7 +433,6 @@ class NodeManager:
                         "search_only": False,
                         "managed": False,
                         "disabled_sources": [],
-                        "skip_db": True,
                         "host": self._unmanaged_external_host,
                         "unique_identifier": 31415,
                         "name": "ENVAR Node (Unmanaged)",
@@ -473,20 +445,16 @@ class NodeManager:
                     self._unmanaged_external_host,
                     self._unmanaged_external_port,
                 )
-        config_data = await self.client._lib_config_manager.get_config(
-            config_folder=self.client._config_folder,
-            java_path=JAVA_EXECUTABLE,
-            enable_managed_node=True,
-            auto_update_managed_nodes=True,
-            localtrack_folder=self.client._config_folder / "music",
-            use_bundled_pylav_external=USE_BUNDLED_EXTERNAL_PYLAV_NODE,
-            use_bundled_lava_link_external=USE_BUNDLED_EXTERNAL_LAVA_LINK_NODE,
-        )
-        if config_data.java_path != JAVA_EXECUTABLE and JAVA_EXECUTABLE != "java" and os.path.exists(JAVA_EXECUTABLE):
-            config_data.java_path = JAVA_EXECUTABLE
-            await config_data.save()
-        if config_data.use_bundled_pylav_external:
-            if await asyncstdlib.all(True for n in nodes_list if n.host != "ll-gb.draper.wtf"):
+        config_data = typing.cast(LibConfigModel, self.client._lib_config_manager.get_config())
+        all_data = await config_data.fetch_all()
+
+        if all_data["java_path"] != JAVA_EXECUTABLE and os.path.exists(JAVA_EXECUTABLE):
+            await config_data.update_java_path(JAVA_EXECUTABLE)
+
+        if all_data["use_bundled_pylav_external"]:
+            if await asyncstdlib.all(
+                True for n in nodes_list if n.host != "ll-gb.draper.wtf"
+            ) and not self.get_node_by_id(PYLAV_BUNDLED_NODES_SETTINGS["ll-gb.draper.wtf"]["unique_identifier"]):
                 base_settings = PYLAV_BUNDLED_NODES_SETTINGS["ll-gb.draper.wtf"]
                 base_settings["host"] = "ll-gb.draper.wtf"
                 base_settings["resume_key"] = f"PyLav/{self.client.lib_version}-{self.client.bot_id}"
@@ -497,7 +465,9 @@ class NodeManager:
                     PYLAV_BUNDLED_NODES_SETTINGS["ll-gb.draper.wtf"]["name"],
                 )
 
-            if await asyncstdlib.all(True for n in nodes_list if n.host != "ll-us-ny.draper.wtf"):
+            if await asyncstdlib.all(
+                True for n in nodes_list if n.host != "ll-us-ny.draper.wtf"
+            ) and not self.get_node_by_id(PYLAV_BUNDLED_NODES_SETTINGS["ll-us-ny.draper.wtf"]["unique_identifier"]):
                 base_settings = PYLAV_BUNDLED_NODES_SETTINGS["ll-us-ny.draper.wtf"]
                 base_settings["resume_key"] = f"PyLav/{self.client.lib_version}-{self.client.bot_id}"
                 nodes_list.append(await self.add_node(**base_settings))
@@ -506,7 +476,9 @@ class NodeManager:
                     "%s already added to connection pool - skipping duplicated connection",
                     PYLAV_BUNDLED_NODES_SETTINGS["ll-us-ny.draper.wtf"]["name"],
                 )
-        if config_data.use_bundled_lava_link_external:
+        if all_data["use_bundled_lava_link_external"] and not self.get_node_by_id(
+            PYLAV_BUNDLED_NODES_SETTINGS["lava.link"]["unique_identifier"]
+        ):
             if await asyncstdlib.all(True for n in nodes_list if n.host != "lava.link"):
                 nodes_list.append(
                     await self.add_node(
