@@ -267,12 +267,13 @@ class PlaylistConfigManager:
         with contextlib.suppress(
             asyncio.exceptions.CancelledError,
         ):
-            old_time_stamp = self.client._config.next_execution_update_bundled_playlists
+            old_time_stamp = await self.client._config.fetch_next_execution_update_bundled_playlists()
+
+            await self.client._config.update_next_execution_update_bundled_playlists(
+                datetime.datetime.now(tz=datetime.timezone.utc)
+                + datetime.timedelta(days=TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS)
+            )
 
-            self.client._config.next_execution_update_bundled_playlists = datetime.datetime.now(
-                tz=datetime.timezone.utc
-            ) + datetime.timedelta(days=TASK_TIMER_UPDATE_BUNDLED_PLAYLISTS_DAYS)
-            await self.client._config.save()
             curated_data = {
                 1: (
                     "Aikaterna's curated tracks",
@@ -296,7 +297,7 @@ class PlaylistConfigManager:
                         LOGGER.error("Built-in playlist couldn't be parsed - %s, report this error", name, exc_info=exc)
                         data = None
                     if not data:
-                        self.client._config.next_execution_update_bundled_playlists = old_time_stamp
+                        await self.client._config.update_next_execution_update_bundled_playlists(old_time_stamp)
                         continue
                     if tracks := [t async for t in asyncstdlib.map(str.strip, data.splitlines()) if t]:
                         LOGGER.info("Updating bundled playlist - %s (%s)", name, id)
@@ -312,11 +313,11 @@ class PlaylistConfigManager:
         with contextlib.suppress(
             asyncio.exceptions.CancelledError,
         ):
-            old_time_stamp = self.client._config.next_execution_update_bundled_external_playlists
-            self.client._config.next_execution_update_bundled_external_playlists = datetime.datetime.now(
-                tz=datetime.timezone.utc
-            ) + datetime.timedelta(days=TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS)
-            await self.client._config.save()
+            old_time_stamp = await self.client._config.fetch_next_execution_update_bundled_external_playlists()
+            await self.client._config.update_next_execution_update_bundled_external_playlists(
+                datetime.datetime.now(tz=datetime.timezone.utc)
+                + datetime.timedelta(days=TASK_TIMER_UPDATE_BUNDLED_EXTERNAL_PLAYLISTS_DAYS)
+            )
 
             # NOTICE: Update the BUNDLED_PLAYLIST_IDS constant in the constants.py file
             curated_data = {
@@ -353,7 +354,7 @@ class PlaylistConfigManager:
                     )
                     data = None
                 if not data:
-                    self.client._config.next_execution_update_bundled_external_playlists = old_time_stamp
+                    await self.client._config.update_next_execution_update_bundled_external_playlists(old_time_stamp)
                     continue
                 if track_list:
                     await self.create_or_update_global_playlist(
@@ -369,10 +370,10 @@ class PlaylistConfigManager:
         with contextlib.suppress(
             asyncio.exceptions.CancelledError,
         ):
-            self.client._config.next_execution_update_external_playlists = datetime.datetime.now(
-                tz=datetime.timezone.utc
-            ) + datetime.timedelta(days=TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS)
-            await self.client._config.save()
+            await self.client._config.update_next_execution_update_external_playlists(
+                datetime.datetime.now(tz=datetime.timezone.utc)
+                + datetime.timedelta(days=TASK_TIMER_UPDATE_EXTERNAL_PLAYLISTS_DAYS)
+            )
 
             async for playlist in self.get_external_playlists(*ids, ignore_ids=BUNDLED_PLAYLIST_IDS):
                 try:
@@ -395,3 +396,7 @@ class PlaylistConfigManager:
                         playlist.id,
                         exc_info=exc,
                     )
+
+    async def count(self) -> int:
+        """Returns the number of playlists in the database."""
+        return await tables.PlaylistRow.count()
